@@ -3,6 +3,7 @@ use Benchmark qw(cmpthese);
 
 use Text::QueryString;
 use Text::QueryString::PP;
+use constant HAVE_URL_ENCODE => eval { require URL::Encode };
 
 # Sneaky. don't do this
 @Text::QueryString::PP::ISA = qw(Text::QueryString);
@@ -17,6 +18,7 @@ my @query_string = (
     "foo=bar&foo=baz&bar=baz",
     "foo_only",
     "foo&bar=baz",
+    "日本語=にほんご&ほげほげ=1&ふがふが",
 );
 
 cmpthese(-1, {
@@ -29,5 +31,14 @@ cmpthese(-1, {
         foreach my $qs (@query_string) {
             my @q = $pp->parse($qs);
         }
-    }
+    },
+    HAVE_URL_ENCODE ? (
+        url_encode => sub {
+            foreach my $qs (@query_string) {
+                my @q = URL::Encode::url_params_flat($qs);
+use Data::Dumper;
+warn Dumper(\@q);
+            }
+        },
+    ) :(),
 });
